<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/334?lang_cible=en
// ** ne pas modifier le fichier **

return [

	// R
	'retour_ligne_auto' => 'Automatic word wrap',
	'retour_ligne_ignore' => 'Ignore word wrap',
	'retour_ligne_manuel' => 'Manual word wrap',
];
